"""
Module: '_onewire' on micropython-v1.19.1-esp8266
"""
# MCU: {'ver': 'v1.19.1', 'build': '', 'platform': 'esp8266', 'port': 'esp8266', 'machine': 'ESP module (1M) with ESP8266', 'release': '1.19.1', 'nodename': 'esp8266', 'name': 'micropython', 'family': 'micropython', 'sysname': 'esp8266', 'version': '1.19.1'}
# Stubber: 1.5.6
from typing import Any


def crc8(*args, **kwargs) -> Any:
    ...


def readbit(*args, **kwargs) -> Any:
    ...


def readbyte(*args, **kwargs) -> Any:
    ...


def reset(*args, **kwargs) -> Any:
    ...


def writebit(*args, **kwargs) -> Any:
    ...


def writebyte(*args, **kwargs) -> Any:
    ...
